@@ -1,4 +1,6 @@
 from django.db import models
+from django.utils.translation import ugettext as _
+from filer.fields.image import FilerImageField
 
 from cms.models import CMSPlugin
 
